pub enum BinaryPolynomialError {
MultiplierDegreeGreaterOrEqualToModulusError,
NotSquareFreePolynomialError,
ParsingPolynomialError,
}Expand description
Error type for binary polynomial operations
Variants
MultiplierDegreeGreaterOrEqualToModulusError
Error when the degree of the polynomial is greater than the modulus on polynomial modular multiplication
NotSquareFreePolynomialError
Error when the given polynomial is not square free, ie it can be expressed as A*A*B, with A, B polynomials
ParsingPolynomialError
Error when parsing polynomial from string